@@ -14,7 +14,7 @@
  * 
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  */
 #include <QtCore/QSettings>
 #include <QtGui/QStatusBar>
@@ -475,7 +475,7 @@ main(int argc, char ** argv)
     QString		tzString;
     static const char	*options = "A:a:Cc:D:g:h:Lo:n:O:p:s:S:T:t:Vv:WzZ:?";
 
-    gettimeofday(&origin, NULL);
+    __pmtimevalNow(&origin);
     __pmSetProgname(argv[0]);
     QApplication a(argc, argv);
     setupEnvironment();
@@ -724,7 +724,7 @@ main(int argc, char ** argv)
     }
     else {
 	liveGroup->defaultTZ(tzLabel, tzString);
-	gettimeofday(&logStartTime, NULL);
+	__pmtimevalNow(&logStartTime);
 	logEndTime.tv_sec = logEndTime.tv_usec = INT_MAX;
 	if ((sts = pmParseTimeWindow(Sflag, Tflag, Aflag, Oflag,
 					&logStartTime, &logEndTime,
